@@ -30,6 +30,7 @@
 #' @param symlink Logical indicating whether to place a symbolic link
 #' to the location in `path_data=`. Default is to place the symbolic link
 #' if the project is a git repository.
+#' @param renv.settings A list of renv settings passed to `renv::scaffold(settings=)`
 #'
 #' @author Daniel D. Sjoberg
 #' @export
@@ -49,6 +50,7 @@
 
 create_project <- function(path, path_data = NULL, template = "default",
                            git = TRUE, renv = TRUE, symlink = git,
+                           renv.settings = NULL,
                            overwrite = NA, open = interactive()) {
   # check if template has function arg override --------------------------------
   if (!is.null(template) && !is.null(attr(template, "arg_override"))) {
@@ -59,7 +61,7 @@ create_project <- function(path, path_data = NULL, template = "default",
       purrr::iwalk(
         function(arg, name) {
           if (!identical(arg, eval(parse(text = name))))
-            ui_done("Using template argument override {ui_code(paste(name, arg, sep = ' = '))}")
+            ui_done("Using template argument override {ui_code(paste(name, deparse(arg, width.cutoff = 200L), sep = ' = '))}")
         }
       )
     list2env(override_arg_list, envir = rlang::current_env())
@@ -104,7 +106,7 @@ create_project <- function(path, path_data = NULL, template = "default",
   if (isTRUE(renv)) {
     ui_done("Initialising {ui_field('renv')} project")
     # set up structure of renv project
-    renv::scaffold(project = path, settings = list(snapshot.type = "all"))
+    renv::scaffold(project = path, settings = renv.settings)
   }
 
   # if user added a path to a script, run it -----------------------------------
@@ -251,6 +253,9 @@ eval_nested_lists <- function(template, path, git, renv) {
 eval_if_call_or_expr <- function(x, path, git, renv)  {
   # strings that may be needed in the evaluation of some strings
   folder_name <- basename(path)
+  folder_first_word <-
+    stringr::str_split(folder_name, pattern = ' |-', simplify = T)[, 1] %>%
+    tolower()
   if (rlang::is_call(x) || rlang::is_expression(x)) x <- eval(x)
   x
 }
